@@ -86,24 +86,22 @@ sento_corpus <- function(corpusdf, do.clean = FALSE) {
   dates <- as.Date(corpusdf$date, format = "%Y-%m-%d")
   if (any(is.na(dates))) stop("Some dates are not in appropriate format. Should be 'yyyy-mm-dd'.")
   else corpusdf$date <- dates
-
   # check if language is provided
   if ("language" %in% cols) {
     nonfeatures <- c(nonfeatures, "language")
-    # if (!all(sapply(corpusdf$language, is_iso_language)))
-    #   stop("Not all text contain ISO 639 code. Check ISOcodes::ISO_639_2 for list of available options.")
   }
-
+  # check if feature names are correctly formatted
   features <- cols[!(cols %in% nonfeatures)]
   if (!is_names_correct(features))
-    stop("At least one feature's name contains '-'. Please provide proper names.")
+    stop("At least one feature name contains '-'. Please provide proper names.")
+
   corpusdf <- corpusdf[, c(nonfeatures, features)]
 
-  info <- "This is a sento_corpus object derived from a quanteda corpus object."
+  info <- "This is a sento_corpus object based on the quanteda corpus object."
 
   if (length(features) == 0) {
     corpusdf[["dummyFeature"]] <- 1
-    warning("No features detected. A 'dummyFeature' feature valued at 1 throughout is added.")
+    message("We detected no features, so we added a dummy feature 'dummyFeature'.")
   } else {
     if (sum(duplicated(features)) > 0) {
       duplics <- unique(features[duplicated(features)])
@@ -114,7 +112,8 @@ sento_corpus <- function(corpusdf, do.clean = FALSE) {
     if (any(!isNumeric)) {
       toDrop <- names(which(!isNumeric))
       corpusdf[, toDrop] <- NULL
-      warning(paste0("Following feature columns are dropped as they are not numeric: ", paste0(toDrop, collapse = ", "), "."))
+      warning(paste0("Following feature columns are dropped as they are not numeric: ",
+                     paste0(toDrop, collapse = ", "), "."))
       if (length(toDrop) == length(isNumeric)) {
         corpusdf[["dummyFeature"]] <- 1
         warning("No remaining feature columns. A 'dummyFeature' feature valued at 1 throughout is added.")
@@ -141,7 +140,7 @@ sento_corpus <- function(corpusdf, do.clean = FALSE) {
   if (do.clean) corpusdf <- clean_texts(corpusdf)
   corp <- quanteda::corpus(x = corpusdf, docid_field = "id", text_field = "texts", metacorpus = list(info = info))
   class(corp) <- c("sento_corpus", class(corp))
-  setorder(corp$documents, "date", na.last=FALSE)
+  data.table::setorder(quanteda::docvars(corp), date) # oldest comes first
   return(corp)
 }
 
@@ -280,7 +279,7 @@ add_features <- function(corpus, featuresdf = NULL, keywords = NULL, do.binary =
 `docvars<-.sento_corpus` <- function(x, field, value) {
   if (!is.null(value)) {
     stop("To add or replace features in a sento_corpus object, use the add_features() function.", call. = FALSE)
-  } else {
+  } else { # delete one or more features
     # xNew <- NextMethod("docvars<-")
     xNew <- x
     class(xNew) <- c("corpus", "list")
@@ -519,13 +518,25 @@ as.sento_corpus <- function(x, dates = NULL, do.clean = FALSE) {
 
 #' @export
 as.data.table.sento_corpus <- function(x, ...) {
-  dt <- data.table::data.table(id = quanteda::docnames(x), x$documents)
+  dt <- data.table::data.table(id = quanteda::docnames(x), texts = quanteda::texts(x), quanteda::docvars(x))
   data.table::setcolorder(dt, c("id", "date", "texts"))
   dt
 }
 
 #' @export
 as.data.frame.sento_corpus <- function(x, ...) {
-  x$documents[, c("date", "texts", colnames(x$documents)[-c(1:2)])]
+  df <- cbind(quanteda::docvars(x), texts = quanteda::texts(x))
+  df[, c("date", "texts", setdiff(colnames(df), c("date", "texts")))]
+}
+
+# this function is directly taken from the quanteda package
+#' @export
+print.sento_corpus <- function(x, ...) {
+  cat("A sento_corpus consisting of ", format(quanteda::ndoc(x), big.mark = ","), " document",
+      if (quanteda::ndoc(x) > 1L) "s" else "", sep = "")
+  if (ncol(quanteda::docvars(x)))
+    cat(" and ", format(ncol(quanteda::docvars(x)), big.mark = ","), " docvar",
+        if (ncol(quanteda::docvars(x)) == 1L) "" else "s", sep = "")
+  cat(".\n")
 }
 
