@@ -13,12 +13,13 @@ reuters <- system.file("texts", "crude", package = "tm")
 
 ### tests from here ###
 
-# sento_corpus
 corpus <- sento_corpus(corpusdf = usnews, do.clean = TRUE)
+
+# sento_corpus
 test_that("Corpus building works and fails when appropriate", {
   expect_equal(c("date", "wsj", "wapo", "economy", "noneconomy"),
                names(docvars(corpus)))
-  expect_warning(corpusDummy <- sento_corpus(corpusdf = usnews[, 1:3]))
+  expect_message(corpusDummy <- sento_corpus(corpusdf = usnews[, 1:3]))
   expect_equal(colnames(quanteda::docvars(corpusDummy)), c("date", "dummyFeature"))
   expect_warning(sento_corpus(corpusdf = cbind(usnews, "notNumeric")))
   expect_warning(sento_corpus(corpusdf = cbind(usnews[, 1:3], usnews[, -c(1:3)] * 100)))
@@ -94,3 +95,21 @@ test_that("Proper data.table and data.frame conversion", {
   expect_true(all(colnames(dt)[-1] == colnames(df)))
 })
 
+# quanteda corpus_*() functions
+res <- quanteda::corpus_reshape(corpus, to = "sentences")
+sam <- quanteda::corpus_sample(corpus, 100)
+seg <- quanteda::corpus_segment(corpus, pattern = "stock", use_docvars = TRUE)
+sub <- quanteda::corpus_subset(corpus, wsj == 1)
+tri <- quanteda::corpus_trim(corpus, "documents", min_ntoken = 300)
+trs <- quanteda::corpus_trim(corpus, "sentences", min_ntoken = 40)
+# trs <- quanteda::corpus_trimsentences(corpus, min_length = 40)
+test_that("quanteda corpus_*() functions keep sento_corpus object intact when expected", {
+  # expect_true(inherits(res, "sento_corpus"))
+  expect_true(inherits(sam, "sento_corpus"))
+  # expect_true(inherits(as.sento_corpus(sam), "sento_corpus"))
+  # expect_true(inherits(seg, "sento_corpus"))
+  expect_true(inherits(sub, "sento_corpus"))
+  expect_true(inherits(tri, "sento_corpus"))
+  # expect_true(inherits(trs, "sento_corpus"))
+})
+
